Numina Reference — Numina 0.20.dev0 documentation

# Numina Reference

Release: | 0.20
Date: | Mar 01, 2019

Warning

This “Reference” is still a work in progress; some of the material is not organized, and several aspects of Numina are not yet covered sufficient detail.

- Numina modules
  - `numina.array` — Array manipulation
  - `numina.core` — Core classes for Pipelines
  - `numina.dal` — Calibration fetching
  - `numina.datamodel` — Model of data
  - `numina.drps` — Loading DRPS
  - `numina.exceptions` — Numina exceptions
  - `numina.frame` — Frame manipulation
  - `numina.logger` — Logging utilities
  - `numina.modeling` — Model for fitting
  - `numina.core.qc` — Quality Control for Numina
  - `numina.store` — Serialization of products
  - `numina.treedict` — Recursive dictionary
  - `numina.types` — Data types
  - `numina.user` — CLI interface
  - `numina.util` — Generic utilities
  - `numina.visualization` — Data visualization
  - `numina.user.xdgdirs` — Base Directories

## Indices and tables

- Index
- Module Index
- Search Page
- Glossary